lilypondparsertools.LilyPondEvent
=================================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__repr__
